bayespy.nodes.Binomial
======================

.. currentmodule:: bayespy.nodes

.. autoclass:: Binomial

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~Binomial.__init__
      ~Binomial.add_plate_axis
      ~Binomial.broadcasting_multiplier
      ~Binomial.delete
      ~Binomial.get_gradient
      ~Binomial.get_mask
      ~Binomial.get_moments
      ~Binomial.get_parameters
      ~Binomial.get_riemannian_gradient
      ~Binomial.get_shape
      ~Binomial.has_plotter
      ~Binomial.initialize_from_parameters
      ~Binomial.initialize_from_prior
      ~Binomial.initialize_from_random
      ~Binomial.initialize_from_value
      ~Binomial.load
      ~Binomial.logpdf
      ~Binomial.lower_bound_contribution
      ~Binomial.lowerbound
      ~Binomial.move_plates
      ~Binomial.observe
      ~Binomial.pdf
      ~Binomial.plot
      ~Binomial.random
      ~Binomial.save
      ~Binomial.set_parameters
      ~Binomial.set_plotter
      ~Binomial.show
      ~Binomial.unobserve
      ~Binomial.update
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
      :toctree: generated/
   
      ~Binomial.dims
      ~Binomial.plates
      ~Binomial.plates_multiplier
   
   